@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Base64FileWriter.h 2185 2006-12-08 17:25:48Z svn $
+ * $Id: Base64FileWriter.h 2244 2006-12-11 17:25:42Z svn $
  *****************************************************************************/
 
 #ifndef BASE64_FILE_WRITER_H
@@ -66,9 +66,9 @@ public:
      * @param[in] size 書き出すサイズ
      * @exception const char * 書き出しに失敗した場合
      */
-    void write(void *buffer, apr_size_t size)
+    void write(void *buffer, apr_size_t buffer_size)
     {
-        write_impl(AS_UCHAR(buffer), &size);
+        write_impl(AS_UCHAR(buffer), &buffer_size);
     };
     /**
      * ファイルへの書き出しを行います．
@@ -78,9 +78,9 @@ public:
      * @param[in,out] size 書き出すサイズ
      * @exception const char * 書き出しに失敗した場合
      */
-    void write(void *buffer, apr_size_t *size)
+    void write(void *buffer, apr_size_t *buffer_size)
     {
-        write_impl(AS_UCHAR(buffer), size);
+        write_impl(AS_UCHAR(buffer), buffer_size);
     };
     /**
      * ファイルを閉じます．
