@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: DownloadFlowController.h 2220 2006-12-10 06:10:27Z svn $
+ * $Id: DownloadFlowController.h 2235 2006-12-10 17:36:52Z svn $
  *****************************************************************************/
 
 #ifndef DOWNLOAD_FLOW_CONTROLLER_H
@@ -37,6 +37,7 @@
 #include "apr_network_io.h"
 #include "AtomicWrapper.h"
 
+#include "FlowController.h"
 #include "Macro.h"
 #include "Uncopyable.h"
 
@@ -45,7 +46,7 @@ using namespace std;
 /**
  * @brief ダウンロードのフロー制御を行うクラス．
  */
-class DownloadFlowController: public Uncopyable
+class DownloadFlowController: public FlowController
 {
 public:
     DownloadFlowController();
@@ -59,12 +60,8 @@ public:
 
 private:
     typedef struct Downloader {
-        union {
-            struct sockaddr_in sin;
-#if APR_HAVE_IPV6
-            struct sockaddr_in6 sin6;
-#endif
-        } ip_address;
+        apr_size_t ip_address_size;
+        apr_uint32_t ip_address[sizeof(address_type)/sizeof(apr_uint32_t)];
         apr_size_t session_count;
     } downloader_t;
 
