@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Macro.h 2165 2006-12-03 19:06:50Z svn $
+ * $Id: Macro.h 2256 2006-12-13 10:28:14Z svn $
  *****************************************************************************/
 
 /**
@@ -47,6 +47,14 @@
 
 using namespace std;
 
+/**
+ * メモリバリアです．
+ */
+#ifndef WIN32
+#define MEMORY_BARRIER __asm__ __volatile__ ("": : :"memory")
+#else
+#define MEMORY_BARRIER
+#endif
 #ifdef __GNUC__
 /**
  * 条件式 x が true になる可能性が高いことをコンパイラに指示するマクロ．
@@ -211,6 +219,12 @@ using namespace std;
  * @param[in] pointer ポインタ
  */
 #define AS_BYTE(pointer) reinterpret_cast<apr_byte_t *>(pointer)
+/**
+ * ポインタを apr_uint32_t * にキャストするマクロ．
+ *
+ * @param[in] pointer ポインタ
+ */
+#define AS_UINT32(pointer) reinterpret_cast<apr_uint32_t *>(pointer)
 /**
  * ポインタを apr_uint16_t * にキャストするマクロ．
  *
