@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItem.h 2242 2006-12-11 15:35:40Z svn $
+ * $Id: UploadItem.h 2279 2006-12-17 19:59:56Z svn $
  *****************************************************************************/
 
 #ifndef UPLOAD_ITEM_H
@@ -36,6 +36,7 @@
 #include "apr_time.h"
 
 #include "TemplateVariable.h"
+#include "Message.h"
 #include "Uncopyable.h"
 #include "Macro.h"
 
@@ -53,26 +54,23 @@ public:
      * @brief アップロードアイテムの情報を表す構造体．
      */
     typedef struct header {
-        char        identifier[ITM_MAX_IDENTIFIER_SIZE];
-        char        version[ITM_MAX_VERSION_SIZE];
-        apr_size_t  id;
-        apr_size_t  index;
-        apr_atomic_t download_count;
-        bool        is_need_sync;
-        union {
-            apr_off_t   file_size;
-            char        dummy[8];
-        };
-        apr_time_t  mtime;
-        char        date[ITM_MAX_DATE_SIZE];
-        char        ip_address[ITM_MAX_IP_ADDRESS_SIZE];
-        char        file_name[ITM_MAX_FILE_NAME_SIZE];
-        char        file_mime[ITM_MAX_FILE_MIME_SIZE];
-        char        file_ext[ITM_MAX_FILE_EXT_SIZE];
-        char        file_digest[ITM_MAX_FILE_DIGEST_SIZE];
-        char        remove_pass[ITM_MAX_REMOVE_PASS_SIZE];
-        char        download_pass[ITM_MAX_DOWNLOAD_PASS_SIZE];
-        char        comment[ITM_MAX_COMMENT_SIZE];
+        char            identifier[ITM_MAX_IDENTIFIER_SIZE];
+        char            version[ITM_MAX_VERSION_SIZE];
+        apr_size_t      id;
+        apr_size_t      index;
+        apr_atomic_t    download_count;
+        bool            is_need_sync;
+        apr_uint64_t    file_size;
+        apr_time_t      mtime;
+        char            date[ITM_MAX_DATE_SIZE];
+        char            ip_address[ITM_MAX_IP_ADDRESS_SIZE];
+        char            file_name[ITM_MAX_FILE_NAME_SIZE];
+        char            file_mime[ITM_MAX_FILE_MIME_SIZE];
+        char            file_ext[ITM_MAX_FILE_EXT_SIZE];
+        char            file_digest[ITM_MAX_FILE_DIGEST_SIZE];
+        char            remove_pass[ITM_MAX_REMOVE_PASS_SIZE];
+        char            download_pass[ITM_MAX_DOWNLOAD_PASS_SIZE];
+        char            comment[ITM_MAX_COMMENT_SIZE];
 
         header() {
             // ゼロクリア
@@ -105,7 +103,7 @@ public:
     {
         return  apr_atomic_read(&(header_.download_count));
     }
-    apr_off_t get_file_size() const
+    apr_uint64_t get_file_size() const
     {
         return header_.file_size;
     }
@@ -178,7 +176,7 @@ public:
      */
     static UploadItem *get_instance(void *memory, apr_size_t item_id,
                                     apr_size_t item_index,
-                                    apr_off_t file_size, apr_time_t mtime,
+                                    apr_uint64_t file_size, apr_time_t mtime,
                                     const char *ip_address,
                                     const char *file_name,
                                     const char *file_mime,
@@ -208,7 +206,7 @@ public:
      */
     static UploadItem *get_instance(apr_pool_t *pool, apr_size_t item_id=0,
                                     apr_size_t item_index=0,
-                                    apr_off_t file_size=0,
+                                    apr_uint64_t file_size=0,
                                     apr_time_t mtime=0,
                                     const char *ip_address="",
                                     const char *file_name="",
