@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemList.h 2255 2006-12-13 09:05:01Z svn $
+ * $Id: UploadItemList.h 2272 2006-12-17 10:21:48Z svn $
  *****************************************************************************/
 
 #ifndef UPLOAD_HEADER_LIST_H
@@ -84,14 +84,13 @@ public:
     {
         return header_list_size_;
     };
-    apr_off_t get_total_file_size() const
+    apr_uint64_t get_total_file_size() const
     {
         return total_file_size_;
     };
-    bool is_full(apr_off_t file_size) const
+    bool is_full(apr_uint64_t file_size) const
     {
-        return (static_cast<apr_uint64_t>(total_file_size_ + file_size) >
-                max_file_size_) ||
+        return ((total_file_size_ + file_size) > max_file_size_) ||
             (size() == max_list_size_);
     };
     /**
@@ -147,7 +146,7 @@ private:
 
     UploadItem::header_t *header_list_;
     apr_size_t header_list_size_;
-    apr_off_t total_file_size_;
+    apr_uint64_t total_file_size_;
     apr_uint64_t max_file_size_;
     apr_size_t max_list_size_;
 };
