@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemListReader.h 2144 2006-11-29 14:54:20Z svn $
+ * $Id: UploadItemListReader.h 2173 2006-12-06 16:12:56Z svn $
  *****************************************************************************/
 
 #ifndef UPOLOAD_ITEM_LIST_READER_H
@@ -57,12 +57,14 @@ public:
      * @param[in] thumb_dir_path サムネイルが保存されているディレクトリ
      * @param[in] shm 共有メモリ
      * @param[in] thumbnail_list サムネイルのリスト
+     * @param[in] max_file_size リストの最大合計ファイルサイズ
      * @param[in] max_list_size リストの最大サイズ
      * @return 掲示板のアップロードアイテム
      */
     static UploadItemList *read(apr_pool_t *pool, const char *data_dir_path,
                                 const char *thumb_dir_path, apr_shm_t *shm,
                                 ThumbnailList *thumbnail_list,
+                                apr_uint64_t max_file_size,
                                 apr_size_t max_list_size);
 
 private:
