@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Auxiliary.cpp 2263 2006-12-14 13:55:27Z svn $
+ * $Id: Auxiliary.cpp 2270 2006-12-16 08:01:59Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -47,7 +47,7 @@
 
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: Auxiliary.cpp 2263 2006-12-14 13:55:27Z svn $");
+SOURCE_INFO_ADD("$Id: Auxiliary.cpp 2270 2006-12-16 08:01:59Z svn $");
 
 void init_atomic(apr_pool_t *pool)
 {
@@ -192,7 +192,7 @@ const char *get_file_ext(const char *file_name)
         }
     }
 
-    return file_ext;
+    return "";
 }
 
 const char *get_mime_image_ext(const char *file_mime)
