@@ -1,7 +1,5 @@
 /******************************************************************************
- * mod_uploader / DirectoryCleaner.cpp
- ******************************************************************************
- * Copyright (C) 2005 Tetsuya Kimata <kimata@acapulco.dyndns.org>
+ * Copyright (C) 2006 Tetsuya Kimata <kimata@acapulco.dyndns.org>
  *
  * All rights reserved.
  *
@@ -24,54 +22,59 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: BinString.cpp 441 2005-07-08 20:14:06Z svn $
+ * $Id: DirectoryCleaner.cpp 2047 2006-11-23 18:57:33Z svn $
  *****************************************************************************/
 
-#include "DirectoryCleaner.h"
+#include "Environment.h"
 
 #include "apr_time.h"
 #include "apr_file_info.h"
 #include "apr_file_io.h"
 
-#ifdef DEBUG
-#include <iostream>
-#endif
+#include "DirectoryCleaner.h"
+#include "Message.h"
+#include "Macro.h"
+#include "SourceInfo.h"
 
+SOURCE_INFO_ADD("$Id: DirectoryCleaner.cpp 2047 2006-11-23 18:57:33Z svn $");
 
 /******************************************************************************
- * public ᥽å
+ * public メソッド
  *****************************************************************************/
-void DirectoryCleaner::cleanOldFiles(apr_pool_t *pool,
-                                     const char *dir_path,
-                                     apr_size_t threshold_sec)
+void DirectoryCleaner::clean_old_files(apr_pool_t *pool,
+                                       const char *dir_path,
+                                       apr_size_t threshold_sec)
 {
     apr_dir_t *dir;
     apr_finfo_t info;
     apr_time_t current_time;
+    char *file_path;
 
     if (apr_dir_open(&dir, dir_path, pool) != APR_SUCCESS) {
-        throw "ǥ쥯ȥɤ߹ޤǤ";
+        THROW(MESSAGE_DIR_OPEN_FAILED);
     }
 
     current_time = apr_time_now();
     try {
-        while (apr_dir_read(&info, APR_FINFO_NAME|APR_FINFO_TYPE|APR_FINFO_MTIME,
+        while (apr_dir_read(&info,
+                            APR_FINFO_NAME|APR_FINFO_TYPE|APR_FINFO_MTIME,
                             dir) == APR_SUCCESS) {
             if ((info.name[0] == '.') || (info.filetype != APR_REG)) {
                 continue;
             }
 
-            if ((current_time-info.mtime) > (threshold_sec*APR_USEC_PER_SEC)) {
-                char *file_path;
+            if ((current_time-info.mtime) < (threshold_sec*APR_USEC_PER_SEC)) {
+                continue;
+            }
 
-                if (apr_filepath_merge(&file_path, dir_path, info.name,
-                                       APR_FILEPATH_NOTABOVEROOT, pool) != APR_SUCCESS) {
-                    throw "Ťե̾ǤޤǤ";
-                }
+            if (apr_filepath_merge(&file_path, dir_path, info.name,
+                                   APR_FILEPATH_NOTABOVEROOT,
+                                   pool) != APR_SUCCESS) {
+                THROW(MESSAGE_FILE_PATH_CREATION_FAILED);
+            }
 
-                if (apr_file_remove(file_path, pool) != APR_SUCCESS) {
-                    throw "ŤեǤޤǤ";
-                }
+            if (apr_file_remove(file_path, pool) != APR_SUCCESS) {
+                THROW(MESSAGE_FILE_REMOVE_FAILED);
             }
         }
 
@@ -83,12 +86,7 @@ void DirectoryCleaner::cleanOldFiles(apr_pool_t *pool,
     }
 }
 
-
-/******************************************************************************
- * private ᥽å
- *****************************************************************************/
-
 // Local Variables:
 // mode: c++
-// buffer-file-coding-system: euc-japan-dos
+// coding: utf-8-dos
 // End:
