@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: DownloadFlowController.cpp 2221 2006-12-10 06:11:38Z svn $
+ * $Id: DownloadFlowController.cpp 2242 2006-12-11 15:35:40Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -33,7 +33,7 @@
 #include "WriteLocker.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: DownloadFlowController.cpp 2221 2006-12-10 06:11:38Z svn $");
+SOURCE_INFO_ADD("$Id: DownloadFlowController.cpp 2242 2006-12-11 15:35:40Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -42,7 +42,7 @@ DownloadFlowController::DownloadFlowController()
   : downloader_count_(0)
 {
     memset(downloader_list_, 0, sizeof(downloader_list_));
-    apr_atomic_set(&lock_, ReadWriteLocker::NOT_LOCKER);
+    (void)apr_atomic_set(&lock_, ReadWriteLocker::NOT_LOCKER);
 }
 
 bool DownloadFlowController::add_session(apr_sockaddr_t *ip_address)
@@ -123,6 +123,7 @@ void DownloadFlowController::dump_list(DownloadFlowController *flow_controller)
 bool DownloadFlowController::downloader_list_add(apr_sockaddr_t *ip_address)
 {
     apr_size_t i;
+    apr_size_t ip_address_size;
 
     if (downloader_count_ == DLD_MAX_SESSION_COUNT) {
         return false;
@@ -140,8 +141,11 @@ bool DownloadFlowController::downloader_list_add(apr_sockaddr_t *ip_address)
     }
 #endif
 
-    memcpy(&(downloader_list_[i].ip_address), &(ip_address->sa),
-           sizeof(ip_address->sa));
+    ip_address_size = get_address_size(ip_address);
+
+    downloader_list_[i].ip_address_size = ip_address_size;
+    memcpy(&(downloader_list_[i].ip_address), get_address(ip_address),
+           ip_address_size);
     downloader_list_[i].session_count = 1;
     downloader_count_++;
 
@@ -152,16 +156,12 @@ DownloadFlowController::downloader_t *
 DownloadFlowController::downloader_list_get(apr_sockaddr_t *ip_address)
 {
     for (apr_size_t i = 0; i < ARRAY_SIZE_OF(downloader_list_); i++) {
-        if (memcmp(&(downloader_list_[i].ip_address), &(ip_address->sa),
-#if APR_HAVE_IPV6
-                   sizeof(struct sockaddr_in6)
-#else
-                   sizeof(struct sockaddr_in)
-#endif
-                   ) != 0) {
-            continue;
+        if (is_address_match(&(downloader_list_[i].ip_address[0]),
+                             downloader_list_[i].ip_address_size,
+                             get_address(ip_address),
+                             get_address_size(ip_address))) {
+            return (downloader_list_ + i);
         }
-        return (downloader_list_ + i);
     }
 
     return NULL;
@@ -169,12 +169,7 @@ DownloadFlowController::downloader_list_get(apr_sockaddr_t *ip_address)
 
 void DownloadFlowController::dump_downloader(downloader_t *downloader)
 {
-    apr_size_t *address;
-
-    // 強引にキャスト
-    address = reinterpret_cast<apr_size_t *>(&(downloader->ip_address));
-
-    cerr << setw(24) << setiosflags(ios::left) << *address;
+    cerr << setw(24) << setiosflags(ios::left) << downloader->ip_address[0];
     cerr << ": " << downloader->session_count << endl;
 }
 
@@ -185,7 +180,7 @@ void DownloadFlowController::dump_downloader(downloader_t *downloader)
 #ifdef DEBUG_DownloadFlowController
 #include "TestRunner.h"
 
-const char DUMMY_IP_ADDRESS[]           = "127.0.0.1";
+apr_sockaddr_t DUMMY_IP_ADDRESS;
 const apr_size_t ATTACK_COUNT           = 100;
 
 void show_usage(const char *prog_name)
@@ -198,13 +193,16 @@ void run_can_download(DownloadFlowController *flow_controller)
     show_test_name("can_download");
 
     for (apr_size_t i = 0; i < DLD_MAX_SESSION_COUNT_PER_IP; i++) {
-        flow_controller->add_session(DUMMY_IP_ADDRESS);
+        flow_controller->add_session(&DUMMY_IP_ADDRESS);
     }
-    if (flow_controller->add_session(DUMMY_IP_ADDRESS)) {
+    if (flow_controller->add_session(&DUMMY_IP_ADDRESS)) {
         THROW(MESSAGE_BUG_FOUND);
     }
-    flow_controller->remove_session(DUMMY_IP_ADDRESS);
-    if (!flow_controller->add_session(DUMMY_IP_ADDRESS)) {
+    flow_controller->remove_session(&DUMMY_IP_ADDRESS);
+    if (!flow_controller->add_session(&DUMMY_IP_ADDRESS)) {
+        THROW(MESSAGE_BUG_FOUND);
+    }
+    if (flow_controller->add_session(&DUMMY_IP_ADDRESS)) {
         THROW(MESSAGE_BUG_FOUND);
     }
 }
@@ -217,6 +215,7 @@ void run_all(apr_pool_t *pool, int argc, const char * const *argv)
 
     DownloadFlowController flow_controller;
     show_line();
+
     run_can_download(&flow_controller);
 }
 
