@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: MmapFileWriter.cpp 2162 2006-12-03 14:36:10Z svn $
+ * $Id: MmapFileWriter.cpp 2272 2006-12-17 10:21:48Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -39,7 +39,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: MmapFileWriter.cpp 2162 2006-12-03 14:36:10Z svn $");
+SOURCE_INFO_ADD("$Id: MmapFileWriter.cpp 2272 2006-12-17 10:21:48Z svn $");
 #endif
 
 #if defined(HAVE_GETPAGESIZE) && !defined(WIN32)
@@ -120,7 +120,7 @@ void MmapFileWriter::write_impl(const void *buffer, apr_size_t size)
 
 void MmapFileWriter::expand()
 {
-    apr_off_t pseudo_size;
+    apr_uint64_t pseudo_size;
 
     block_index_++;
     pseudo_size = BLOCK_SIZE * block_index_;
