@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: PostFlowController.cpp 2220 2006-12-10 06:10:27Z svn $
+ * $Id: PostFlowController.cpp 2242 2006-12-11 15:35:40Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -32,7 +32,7 @@
 #include "WriteLocker.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: PostFlowController.cpp 2220 2006-12-10 06:10:27Z svn $");
+SOURCE_INFO_ADD("$Id: PostFlowController.cpp 2242 2006-12-11 15:35:40Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -42,7 +42,7 @@ PostFlowController::PostFlowController(apr_size_t min_post_interval_sec)
     poster_top_(0),
     poster_tail_(0)
 {
-    apr_atomic_set(&lock_, ReadWriteLocker::NOT_LOCKER);
+    (void)apr_atomic_set(&lock_, ReadWriteLocker::NOT_LOCKER);
 }
 
 bool PostFlowController::can_post(apr_sockaddr_t *ip_address)
@@ -125,6 +125,8 @@ void PostFlowController::dump_list(PostFlowController *flow_controller)
  *****************************************************************************/
 void PostFlowController::poster_list_add(apr_sockaddr_t *ip_address)
 {
+    apr_size_t ip_address_size;
+
     poster_top_++;
     if (poster_top_ == ARRAY_SIZE_OF(poster_list_)) {
         poster_top_ = 0;
@@ -136,8 +138,11 @@ void PostFlowController::poster_list_add(apr_sockaddr_t *ip_address)
         }
     }
 
-    memcpy(&(poster_list_[poster_top_].ip_address), &(ip_address->sa),
-           sizeof(ip_address->sa));
+    ip_address_size = get_address_size(ip_address);
+
+    poster_list_[poster_top_].ip_address_size = ip_address_size;
+    memcpy(&(poster_list_[poster_top_].ip_address), get_address(ip_address),
+           ip_address_size);
     poster_list_[poster_top_].time = apr_time_now();
 }
 
@@ -167,11 +172,12 @@ apr_time_t PostFlowController::poster_list_is_contain(apr_sockaddr_t *ip_address
 
     i = poster_top_;
     do {
-        if (memcmp(&(poster_list_[i].ip_address), &(ip_address->sa),
-                   sizeof(ip_address->sa)) != 0) {
-            continue;
+        if (is_address_match(&(poster_list_[i].ip_address[0]),
+                             poster_list_[i].ip_address_size,
+                             get_address(ip_address),
+                             get_address_size(ip_address))) {
+            return poster_list_[i].time;
         }
-        return poster_list_[i].time;
     } while ((i = (i == 0)
               ? (ARRAY_SIZE_OF(poster_list_)-1)
               : (i-1)) != poster_tail_);
@@ -181,12 +187,7 @@ apr_time_t PostFlowController::poster_list_is_contain(apr_sockaddr_t *ip_address
 
 void PostFlowController::dump_poster(poster_t *poster)
 {
-    apr_size_t *address;
-
-    // 強引にキャスト
-    address = reinterpret_cast<apr_size_t *>(&(poster->ip_address));
-
-    cerr << *address << endl;
+    cerr << poster->ip_address[0] << endl;
 }
 
 
@@ -196,7 +197,7 @@ void PostFlowController::dump_poster(poster_t *poster)
 #ifdef DEBUG_PostFlowController
 #include "TestRunner.h"
 
-const char DUMMY_IP_ADDRESS[]           = "127.0.0.1";
+apr_sockaddr_t DUMMY_IP_ADDRESS;
 const apr_time_t MIN_POST_INTERVAL_SEC  = 1;
 const apr_size_t ATTACK_COUNT           = 100;
 
@@ -211,10 +212,10 @@ void run_can_post(PostFlowController *flow_controller)
 
     show_test_name("can_post");
 
-    flow_controller->regist_post(DUMMY_IP_ADDRESS);
+    flow_controller->regist_post(&DUMMY_IP_ADDRESS);
 
     for (i = 0; i < ATTACK_COUNT; i++) {
-        if (flow_controller->can_post(DUMMY_IP_ADDRESS)) {
+        if (flow_controller->can_post(&DUMMY_IP_ADDRESS)) {
             break;
         }
         apr_sleep(100000);
