@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ThumbnailList.cpp 2255 2006-12-13 09:05:01Z svn $
+ * $Id: ThumbnailList.cpp 2279 2006-12-17 19:59:56Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -37,7 +37,7 @@
 #include "Auxiliary.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: ThumbnailList.cpp 2255 2006-12-13 09:05:01Z svn $");
+SOURCE_INFO_ADD("$Id: ThumbnailList.cpp 2279 2006-12-17 19:59:56Z svn $");
 
 #define AS_THUMBNAIL_LIST(pointer)  reinterpret_cast<ThumbnailList *>(pointer)
 
@@ -65,6 +65,10 @@ void ThumbnailList::add(apr_size_t item_id)
 
     thumbnail_list_size = size();
 
+    if (thumbnail_list_size == max_list_size_) {
+        THROW(MESSAGE_BUG_FOUND);
+    }
+
     // MEMO: thumbnail_list_ は item_id に基づいて降順に並んでいる
 
     i = get_insert_index(item_id);
@@ -90,6 +94,10 @@ void ThumbnailList::remove(apr_size_t item_id)
 
     thumbnail_list_size = size();
 
+    if (thumbnail_list_size == 0) {
+        THROW(MESSAGE_BUG_FOUND);
+    }
+
     i = get_index_by_id(item_id);
     if (i == thumbnail_list_size) {
         // リスト中に存在しない
