@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemList.cpp 2279 2006-12-17 19:59:56Z svn $
+ * $Id: UploadItemList.cpp 2281 2006-12-18 14:26:48Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -38,7 +38,7 @@
 #include "Auxiliary.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItemList.cpp 2279 2006-12-17 19:59:56Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemList.cpp 2281 2006-12-18 14:26:48Z svn $");
 
 #define AS_UHEADER(pointer)     reinterpret_cast<UploadItem::header_t *>(pointer)
 #define AS_UITEM_LIST(pointer)  reinterpret_cast<UploadItemList *>(pointer)
@@ -259,7 +259,7 @@ void UploadItemList::dump_date(apr_pool_t *pool, apr_time_t time)
 #ifdef DEBUG_UploadItemList
 #include "TestRunner.h"
 
-static const apr_uint64_t TEST_FILE_SIZE    = 1*1024L*1024L*1024; // 1GB
+static const apr_uint64_t TEST_FILE_SIZE    = 1*1024LL*1024LL*1024LL; // 1GB
 static const apr_size_t MAX_LIST_SIZE       = 100;
 static const apr_uint64_t MAX_FILE_SIZE     = TEST_FILE_SIZE * MAX_LIST_SIZE / 2;
 
