@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemVariableCreator.cpp 2175 2006-12-06 17:27:48Z svn $
+ * $Id: UploadItemVariableCreator.cpp 2279 2006-12-17 19:59:56Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -32,7 +32,7 @@
 #include "Auxiliary.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItemVariableCreator.cpp 2175 2006-12-06 17:27:48Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemVariableCreator.cpp 2279 2006-12-17 19:59:56Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -256,16 +256,16 @@ void run_all(apr_pool_t *pool, int argc, const char * const *argv)
         THROW(MESSAGE_TMPL_FILE_NOT_FOUND);
     }
 
-    item_list_shm = create_shm(pool,
-                               UploadItemList::get_memory_size(MAX_LIST_SIZE));
-    thumbnail_list_shm = create_shm(pool,
-                                    ThumbnailList::get_memory_size(MAX_LIST_SIZE));
+    item_list_shm = create_shm
+        (pool, UploadItemList::get_memory_size(MAX_LIST_SIZE));
+    thumbnail_list_shm = create_shm
+        (pool, ThumbnailList::get_memory_size(MAX_LIST_SIZE));
 
-    thumbnail_list = ThumbnailList::get_instance(thumbnail_list_shm,
-                                                 MAX_LIST_SIZE);
-    item_list = UploadItemListReader::read(pool, data_dir_path, data_dir_path,
-                                           item_list_shm, thumbnail_list,
-                                           MAX_FILE_SIZE, MAX_LIST_SIZE);
+    thumbnail_list = ThumbnailList::get_instance
+        (thumbnail_list_shm, MAX_LIST_SIZE);
+    item_list = UploadItemListReader::read
+        (pool, data_dir_path, data_dir_path, item_list_shm, thumbnail_list,
+         MAX_FILE_SIZE, MAX_LIST_SIZE);
 
     show_item("data dir", data_dir_path);
     show_item("template file", tmpl_file_path);
