@@ -22,11 +22,23 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemWriter.cpp 2246 2006-12-12 15:06:22Z svn $
+ * $Id: UploadItemWriter.cpp 2271 2006-12-16 20:15:22Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
 
+#ifdef MAKE_THUMBNAIL
+#ifndef WIN32
+#define USE_FORK
+#endif
+#endif
+
+#ifdef USE_FORK
+#include <unistd.h>
+#include <sys/types.h>
+#include <sys/wait.h>
+#endif
+
 #include "UploadItemWriter.h"
 #include "UploadItem.h"
 #include "TemporaryPool.h"
@@ -36,7 +48,7 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItemWriter.cpp 2246 2006-12-12 15:06:22Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemWriter.cpp 2271 2006-12-16 20:15:22Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -122,6 +134,36 @@ void UploadItemWriter::write_file(apr_pool_t *pool, UploadItem *uitem,
 
 #ifdef MAKE_THUMBNAIL
 bool UploadItemWriter::write_thumb(apr_pool_t *pool, UploadItem *uitem)
+{
+#ifdef USE_FORK
+    static const int TIMEOUT_SEC    = 100;
+    static const int NICE_VALUE     = 20;
+
+    pid_t pid;
+    int status;
+
+    switch (pid = fork()) {
+    case 0: // 子プロセス．
+        apr_pool_create(&pool, NULL);
+
+        // 念のため nice 値を設定
+        nice(NICE_VALUE);
+        alarm(TIMEOUT_SEC);
+
+        exit(write_thumb_impl(pool, uitem) ? EXIT_SUCCESS : EXIT_FAILURE);
+    case -1: // エラー．
+        return false;
+    default: // 親プロセス
+        waitpid(pid, &status, 0);
+
+        return WIFEXITED(status) && (WEXITSTATUS(status) == EXIT_SUCCESS);
+    }
+#else
+    return write_thumb_impl(pool, uitem);
+#endif
+}
+
+bool UploadItemWriter::write_thumb_impl(apr_pool_t *pool, UploadItem *uitem)
 {
     apr_size_t thumb_width;
     apr_size_t thumb_height;
