@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploaderConfig.cpp 2199 2006-12-09 02:45:03Z svn $
+ * $Id: UploaderConfig.cpp 2280 2006-12-18 14:21:07Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -46,7 +46,7 @@
 #include "Message.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploaderConfig.cpp 2199 2006-12-09 02:45:03Z svn $");
+SOURCE_INFO_ADD("$Id: UploaderConfig.cpp 2280 2006-12-18 14:21:07Z svn $");
 
 #define PARAM_PREFIX "Uploader"
 
@@ -120,10 +120,10 @@ UploaderConfig::UploaderConfig(apr_pool_t *pool)
     data_dir_path(""),
     file_dir_path(""),
     temp_dir_path(""),
-    total_file_size_limit(0),
-    total_file_number_limit(0),
-    file_size_limit(0),
-    per_page_item_number(0),
+    total_file_size_limit(DEFAULT_TOTAL_FILE_SIZE_LIMIT),
+    total_file_number_limit(DEFAULT_TOTAL_FILE_NUMBER_LIMIT),
+    file_size_limit(DEFAULT_FILE_SIZE_LIMIT),
+    per_page_item_number(DEFAULT_PER_PAGE_ITEM_NUMBER),
     is_debug_mode(false),
     pool_(pool),
     is_active_(false),
