@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_handler.cpp 2271 2006-12-16 20:15:22Z svn $
+ * $Id: uploader_handler.cpp 2273 2006-12-17 13:35:43Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -56,7 +56,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2271 2006-12-16 20:15:22Z svn $");
+SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2273 2006-12-17 13:35:43Z svn $");
 #endif
 
 #define IS_REQUEST_COMMAND(arg, command) \
@@ -87,6 +87,8 @@ static const char UPLOAD_COMMAND[]              = "upload";
 static const char PROGRESS_DATA_COMMAND[]       = "progress_data";
 static const char ADMIN_COMMAND[]               = "admin";
 
+static const char PAGE_CONTENT_TYPE[]           = "text/html; charset=EUC-JP";
+
 #ifdef DEBUG
 static const char INFO_COMMAND[]                = "info";
 #endif
@@ -98,7 +100,7 @@ static int redirect(typename Response::Handle *r, typename Response::Writer& o,
     // POST した後にページを簡単にリロードできるようにするため，HTML で
     // リダイレクトさせる．
 
-    Response::set_content_type(r, "text/html");
+    Response::set_content_type(r, PAGE_CONTENT_TYPE);
 
     o.write("<?xml version=\"1.0\" encoding=\"EUC-JP\"?>\n");
     o.write("<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.1//EN\" "
@@ -139,7 +141,7 @@ static int error(typename Response::Handle *r,
                  typename Response::Writer& o,
                  UploaderConfig *config, const char *message)
 {
-    Response::set_content_type(r, "text/html");
+    Response::set_content_type(r, PAGE_CONTENT_TYPE);
 
     try {
         UploaderTemplate *tmpl;
@@ -202,7 +204,7 @@ static int index(typename Response::Handle *r, UploaderConfig *config,
     apr_size_t page_no;
     apr_size_t page_count;
 
-    Response::set_content_type(r, "text/html");
+    Response::set_content_type(r, PAGE_CONTENT_TYPE);
 #ifndef DEBUG
     Response::set_modified_time(r, config->get_item_manager()->get_mtime());
     Response::set_last_modified(r, config->get_item_manager()->get_mtime());
@@ -326,7 +328,7 @@ static int thumbnail(typename Response::Handle *r, UploaderConfig *config,
     apr_size_t page_no;
     apr_size_t page_count;
 
-    Response::set_content_type(r, "text/html");
+    Response::set_content_type(r, PAGE_CONTENT_TYPE);
 #ifndef DEBUG
     Response::set_modified_time(r, config->get_item_manager()->get_mtime());
     Response::set_last_modified(r, config->get_item_manager()->get_mtime());
@@ -396,7 +398,7 @@ static int thumbnail(typename Response::Handle *r, UploaderConfig *config,
 template<class Response>
 static int upload_impl(typename Response::Handle *r, UploaderConfig *config,
                        const char *file_name, const char *file_mime,
-                       apr_off_t file_size, const char *file_digest,
+                       apr_uint64_t file_size, const char *file_digest,
                        const char *file_temp_path, const char *remove_pass,
                        const char *download_pass, const char *comment)
 {
@@ -428,7 +430,7 @@ static int upload(typename Response::Handle *r, UploaderConfig *config,
 
     const char *file_name;
     const char *file_mime;
-    apr_off_t file_size;
+    apr_uint64_t file_size;
     const char *file_digest;
     const char *file_temp_path;
     const char *remove_pass;
@@ -541,7 +543,7 @@ static int mail_upload(typename Response::Handle *r, UploaderConfig *config,
 
     const char *file_name;
     const char *file_mime;
-    apr_off_t file_size;
+    apr_uint64_t file_size;
     const char *file_digest;
     const char *file_temp_path;
     const char *remove_pass;
@@ -593,7 +595,7 @@ template<class Response>
 static int input_pass(typename Response::Handle *r, UploaderConfig *config,
                       UploadItem *uitem)
 {
-    Response::set_content_type(r, "text/html");
+    Response::set_content_type(r, PAGE_CONTENT_TYPE);
 
     if (Response::is_head_method(r)) {
         return OK;
@@ -708,8 +710,9 @@ static int download(typename Response::Handle *r, UploaderConfig *config,
                 return OK;
             }
 
-            item_file = config->get_item_manager()->get_item_file(r->pool,
-                                                                  item_id);
+            item_file = config->get_item_manager()
+                ->get_item_file(r->pool, item_id,
+                                Response::Writer::is_sendfile_enabled(r));
 
             Response::set_accept_ranges(r);
 
@@ -855,7 +858,7 @@ static int admin(typename Response::Handle *r, UploaderConfig *config,
     apr_size_t page_no;
     apr_size_t page_count;
 
-    Response::set_content_type(r, "text/html");
+    Response::set_content_type(r, PAGE_CONTENT_TYPE);
 #ifndef DEBUG
     Response::set_modified_time(r, config->get_item_manager()->get_mtime());
     Response::set_last_modified(r, config->get_item_manager()->get_mtime());
